@@ -20,12 +20,13 @@ class ApiData():
         self.on_greeks = None
         self.on_greekSnapshot = None
         self.IsConnectionEstablished = False
-    async def initialize(self, api_token, api_host,protocol="http"):
+    async def initialize(self, api_token, api_host):
         """
         initialize the api with token for authentication and authorization
         """
         api_token = quote(api_token)
         print(api_token)
+        protocol = "http"
         host = api_host
         # host = "localhost:5011"
         hub_url = f"{protocol}://{host}/api/fda/apidata/stream?api_token={api_token}"
@@ -172,6 +173,12 @@ class ApiData():
     async def subscribeSegments(self, needSnapshot = False):
         res = await connection.invoke("SubscribeSegments", [needSnapshot])
         return res
+
+    async def subscribeOptionChain(self, spotName, expiryDate):
+        await connection.invoke("SubscribeChain", [spotName, expiryDate])
+            
+    async def unsubscribeOptionChain(self, spotName, expiryDate):
+        await connection.invoke("UnsubscribeChain", [spotName, expiryDate])
         
     # endregion
 
